import { SdkEmitterOptions } from "@azure-tools/typespec-client-generator-core";
import { EmitContext, JSONSchemaType } from "@typespec/compiler";
import { LoggerLevel } from "./lib/logger-level.js";
import { CodeModel } from "./type/code-model.js";
/**
 * The emitter options for the CSharp emitter.
 * @beta
 */
export interface CSharpEmitterOptions extends SdkEmitterOptions {
    "api-version"?: string;
    outputFile?: string;
    logFile?: string;
    "unreferenced-types-handling"?: "removeOrInternalize" | "internalize" | "keepAll";
    "new-project"?: boolean;
    "clear-output-folder"?: boolean;
    "save-inputs"?: boolean;
    debug?: boolean;
    logLevel?: LoggerLevel;
    "disable-xml-docs"?: boolean;
    "generator-name"?: string;
    "emitter-extension-path"?: string;
    "update-code-model"?: (model: CodeModel) => CodeModel;
}
/**
 * The JSON schema for the CSharp emitter options.
 * @beta
 */
export declare const CSharpEmitterOptionsSchema: JSONSchemaType<CSharpEmitterOptions>;
/**
 * The default options for the CSharp emitter.
 * @beta
 */
export declare const defaultOptions: {
    "api-version": string;
    outputFile: string;
    logFile: string;
    "new-project": boolean;
    "clear-output-folder": boolean;
    "save-inputs": boolean;
    "generate-protocol-methods": boolean;
    "generate-convenience-methods": boolean;
    "package-name": undefined;
    debug: undefined;
    logLevel: LoggerLevel;
    "generator-name": string;
    "emitter-extension-path": undefined;
    "update-code-model": (model: CodeModel) => CodeModel;
};
/**
 * Resolves the options for the CSharp emitter.
 * @param context - The emit context.
 * @returns The resolved options.
 * @beta
 */
export declare function resolveOptions(context: EmitContext<CSharpEmitterOptions>): {
    outputFile: string;
    logFile: string;
    "api-version": string;
    "unreferenced-types-handling"?: "removeOrInternalize" | "internalize" | "keepAll";
    "new-project": boolean;
    "clear-output-folder": boolean;
    "save-inputs": boolean;
    debug: boolean;
    logLevel: LoggerLevel;
    "disable-xml-docs"?: boolean;
    "generator-name": string;
    "emitter-extension-path": string;
    "update-code-model": (model: CodeModel) => CodeModel;
    "generate-protocol-methods": boolean;
    "generate-convenience-methods": boolean;
    "package-name": string;
    "flatten-union-as-enum"?: boolean;
    "examples-directory"?: string;
    "examples-dir"?: string;
    "emitter-name"?: string;
};
//# sourceMappingURL=options.d.ts.map